@@ -11,6 +11,7 @@ use super::models::{ConventionalBody, ConventionalSubject};
 
 pub fn prompt_body(previous_body: &ConventionalBody) -> Result<Option<String>> {
     let mut body_ui = Editor::new("description")
+        .with_file_extension("COMMIT_EDITMSG")
         .with_predefined_text(&previous_body.0)
         .with_help_message("A body (if any)");
 
@@ -43,10 +44,7 @@ pub fn prompt_subject(previous_subject: &ConventionalSubject) -> Result<String>
         subject_ui.with_default(&previous_subject.0)
     };
 
-    subject_ui
-        .with_default(&previous_subject.0)
-        .prompt()
-        .into_diagnostic()
+    subject_ui.prompt().into_diagnostic()
 }
 
 pub fn prompt_breaking(previous_breaking: &str) -> Result<Option<String>> {
@@ -129,7 +127,8 @@ pub fn ask_user(
 }
 
 pub fn ask_fallback(previous_text: &'_ str) -> Result<CommitMessage<'_>> {
-    Ok(Editor::new("Non-conventional editor")
+    Ok(Editor::new("Non-conventional editor.rs")
+        .with_file_extension("COMMIT_EDITMSG")
         .with_predefined_text(previous_text)
         .with_help_message("This commit isn't conventional")
         .prompt()
